# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import pulse_pb2 as pulse__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in pulse_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class PulseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Publish = channel.unary_unary(
                '/pulse.v1.PulseService/Publish',
                request_serializer=pulse__pb2.PublishRequest.SerializeToString,
                response_deserializer=pulse__pb2.PublishResponse.FromString,
                _registered_method=True)
        self.Consume = channel.unary_stream(
                '/pulse.v1.PulseService/Consume',
                request_serializer=pulse__pb2.ConsumeRequest.SerializeToString,
                response_deserializer=pulse__pb2.ConsumeResponse.FromString,
                _registered_method=True)
        self.CommitOffset = channel.unary_unary(
                '/pulse.v1.PulseService/CommitOffset',
                request_serializer=pulse__pb2.CommitOffsetRequest.SerializeToString,
                response_deserializer=pulse__pb2.CommitOffsetResponse.FromString,
                _registered_method=True)
        self.CreateTopic = channel.unary_unary(
                '/pulse.v1.PulseService/CreateTopic',
                request_serializer=pulse__pb2.CreateTopicRequest.SerializeToString,
                response_deserializer=pulse__pb2.CreateTopicResponse.FromString,
                _registered_method=True)


class PulseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Publish(self, request, context):
        """Publish sends a message to a topic.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Consume(self, request, context):
        """Consume reads messages from a topic as a stream.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommitOffset(self, request, context):
        """CommitOffset commits the offset for a consumer group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTopic(self, request, context):
        """CreateTopic creates a new topic.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PulseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Publish': grpc.unary_unary_rpc_method_handler(
                    servicer.Publish,
                    request_deserializer=pulse__pb2.PublishRequest.FromString,
                    response_serializer=pulse__pb2.PublishResponse.SerializeToString,
            ),
            'Consume': grpc.unary_stream_rpc_method_handler(
                    servicer.Consume,
                    request_deserializer=pulse__pb2.ConsumeRequest.FromString,
                    response_serializer=pulse__pb2.ConsumeResponse.SerializeToString,
            ),
            'CommitOffset': grpc.unary_unary_rpc_method_handler(
                    servicer.CommitOffset,
                    request_deserializer=pulse__pb2.CommitOffsetRequest.FromString,
                    response_serializer=pulse__pb2.CommitOffsetResponse.SerializeToString,
            ),
            'CreateTopic': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTopic,
                    request_deserializer=pulse__pb2.CreateTopicRequest.FromString,
                    response_serializer=pulse__pb2.CreateTopicResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'pulse.v1.PulseService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('pulse.v1.PulseService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class PulseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pulse.v1.PulseService/Publish',
            pulse__pb2.PublishRequest.SerializeToString,
            pulse__pb2.PublishResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Consume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/pulse.v1.PulseService/Consume',
            pulse__pb2.ConsumeRequest.SerializeToString,
            pulse__pb2.ConsumeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CommitOffset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pulse.v1.PulseService/CommitOffset',
            pulse__pb2.CommitOffsetRequest.SerializeToString,
            pulse__pb2.CommitOffsetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateTopic(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/pulse.v1.PulseService/CreateTopic',
            pulse__pb2.CreateTopicRequest.SerializeToString,
            pulse__pb2.CreateTopicResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
